@@ -255,19 +255,19 @@ def prepare_sliders(
 
 
 def create_slider(symbol: sp.Symbol) -> Slider:
-    """Create an `int` or `float` slider, depending on Symbol assumptions.
+    r"""Create an `int` or `float` slider, depending on Symbol assumptions.
 
     The description for the slider is rendered as LaTeX from the
     `~sympy.core.symbol.Symbol` name.
 
     >>> import sympy as sp
     >>> from symplot import create_slider
-    >>> create_slider(sp.Symbol("y"))
-    FloatSlider(value=0.0, description='$y$')
-    >>> create_slider(sp.Symbol("n", integer=True))
-    IntSlider(value=0, description='$n$')
+    >>> create_slider(sp.Symbol("a"))
+    FloatSlider(value=0.0, description='\\(a\\)')
+    >>> create_slider(sp.Symbol("n0", integer=True))
+    IntSlider(value=0, description='\\(n_{0}\\)')
     """
-    description = f"${sp.latex(symbol)}$"
+    description = fR"\({sp.latex(symbol)}\)"
     if symbol.is_integer:
         return IntSlider(description=description)
     return FloatSlider(description=description)
